@@ -34,17 +34,23 @@ class CNTV(Base):
         }
         response = self.session.get(self.getHttpVideoInfo_url, params=params)
         response_json = response.json()
+        download_url, flag = [], False
         for video_type in response_json['video']:
             for support_type in ['chapters4', 'chapters3', 'chapters2', 'chapters', 'lowChapters']:
                 if support_type == video_type:
-                    download_url = response_json['video'][video_type][0]['url']
+                    for item in response_json['video'][video_type]:
+                        download_url.append(item['url'])
+                    flag = True
                     break
+            if flag: break
+        if len(download_url) == 1: download_url = download_url[0]
         videoinfo = {
             'source': self.source,
             'download_url': download_url,
             'savedir': self.config['savedir'],
             'savename': '_'.join([self.source, filterBadCharacter(response_json.get('title', f'视频走丢啦_{time.time()}'))]),
             'ext': 'mp4',
+            'split_ext': 'mp4',
         }
         return [videoinfo]
     '''初始化'''
